aboutsummaryrefslogtreecommitdiffstats
path: root/src/ui/MainWindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/ui/MainWindow.cpp')
-rw-r--r--src/ui/MainWindow.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/ui/MainWindow.cpp b/src/ui/MainWindow.cpp
index b986782b..cc04f246 100644
--- a/src/ui/MainWindow.cpp
+++ b/src/ui/MainWindow.cpp
@@ -1,7 +1,7 @@
/**
* This file is part of GPGFrontend.
*
* GPGFrontend is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
@@ -32,7 +32,7 @@ namespace GpgFrontend::UI {
MainWindow::MainWindow() {
networkAccessManager = new QNetworkAccessManager(this);
- auto waitingDialog = new WaitingDialog(tr("Loading Gnupg"), this);
+ auto waitingDialog = new WaitingDialog(_("Loading Gnupg"), this);
QString baseUrl =
"https://api.github.com/repos/saturneric/gpgfrontend/releases/latest";
@@ -57,9 +57,9 @@ MainWindow::MainWindow() {
// Check Context Status
if (!GpgContext::GetInstance().good()) {
QMessageBox::critical(
- nullptr, tr("ENV Loading Failed"),
- tr("Gnupg is not installed correctly, please follow the ReadME "
- "instructions to install gnupg and then open GPGFrontend."));
+ nullptr, _("ENV Loading Failed"),
+ _("Gnupg is not installed correctly, please follow the ReadME "
+ "instructions to install gnupg and then open GpgFrontend."));
QCoreApplication::quit();
exit(0);
}
@@ -1,7 +1,7 @@
/**
- * This file is part of GPGFrontend.
+ * This file is part of GpgFrontend.
*
@@ -1,7 +1,7 @@
*
- * GPGFrontend is free software: you can redistribute it and/or modify
+ * GpgFrontend is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or